@@ -1,6 +1,6 @@
 class PubSubTopics:
-    bits_v1 = 'channel-bits-events-v1.'
-    # bits_v2 = 'channel-bits-events-v2.'
+    # bits_v1 = 'channel-bits-events-v1.'
+    bits = 'channel-bits-events-v2.'
     bits_badge_notification = 'channel-bits-badge-unlocks.'
     channel_points = 'channel-points-channel-v1.'
     channel_subscriptions = 'channel-subscribe-events-v1.'
